@@ -13,7 +13,7 @@ from types import MethodType, FunctionType
 from functools import partial, partialmethod, wraps, update_wrapper
 from collections import OrderedDict
 from collections.abc import Iterable
-from itertools import product
+from itertools import product, chain
 from abc import ABC
 
 import numpy as np
@@ -1175,7 +1175,8 @@ class Residue(Entity):
                 temp_atom = getattr(self.type, atom_name)
                 self_position = np.array([getattr(temp_atom, i) for i in "xyz"])
                 self_position = np.dot(rotation, (self_position - center1)) + center2
-                for connected_atom in self.type.connectivity[temp_atom]:
+                tofind = self.type.connectivity[temp_atom] or self.atoms
+                for connected_atom in tofind:
                     if connected_atom.name in t:
                         connected_position = np.array([getattr(connected_atom, i) for i in "xyz"])
                         connected_position = np.dot(rotation, (connected_position - center1)) + center2
@@ -1967,6 +1968,7 @@ def _add(self, other, deepcopy, link):
         res_b = other_molecule.residues[0]
         new_molecule.residues += other_molecule.residues
         new_molecule.residue_links |= other_molecule.residue_links
+        getattr(new_molecule, "_residue_links_map").update(getattr(other_molecule, "_residue_links_map"))
         if link and res_a and res_a.type.tail and res_b.type.head:
             atom1 = res_a.name2atom(res_a.type.tail)
             atom2 = res_b.name2atom(res_b.type.head)
